function [divF] = divergence(F,coeff)
% compute the divergence of the gradient of f
% multiplied by a diffusion coefficient
% forward difference scheme
%
% Copyright 2006 Paolo Favaro (p.favaro@hw.ac.uk)
% 
% School of Engineering and Physical Sciences
% Heriot-Watt University, Edinburgh, UK
% 
% Last revision: August 2006
%
% This program can be used only for research purposes.
% This program is distributed WITHOUT ANY WARRANTY; 
% without even the implied warranty of MERCHANTABILITY 
% or FITNESS FOR A PARTICULAR PURPOSE.

[nri,nrj]=size(F);
Gxx = zeros(nri,nrj);
Gyy = zeros(nri,nrj);
Gx(:,2:nrj) = diff(F,1,2);
Gy(2:nri,:) = diff(F,1,1);
% diffusion coefficient
Gxcoeff = Gx.*coeff;
Gycoeff = Gy.*coeff;
Gxx(:,1:nrj-1) = diff(Gxcoeff,1,2);
Gyy(1:nri-1,:) = diff(Gycoeff,1,1);
divF = Gxx+Gyy;
return